@@ -36,22 +36,25 @@ async def request_client():
 
 @router.on_event("startup")
 async def login():
-    async def _refreshIdentity() -> NoReturn:
+    async def refresh_identity() -> NoReturn:
         while True:
-            logger.info("Start trying to login pixiv account")
+            logger.info("Trying to refresh Pixiv account identity.")
             try:
-                await PixivAPIRoot.login()
+                account_data = await PixivAPIRoot.login()
             except Exception:
                 logger.exception("Exception occurred during trying to login account:")
-            await asyncio.sleep(
-                PixivConstants.CONFIG["account"]["refresh-interval"].as_number()
+                continue
+            logger.opt(colors=True).info(
+                "<b><g>Successfully</g></b> logged in Pixiv account as "
+                f"<b><e>{account_data.user.name}</e>({account_data.user.account})</b>."
             )
+            await asyncio.sleep(account_data.expires_in)
 
     await PixivAPIRoot.login()
-    asyncio.ensure_future(_refreshIdentity())
+    asyncio.ensure_future(refresh_identity())
 
 
-@router.get("/", summary="Pixiv API 兼容实现")
+@router.get("/", summary="Pixiv API 兼容实现", deprecated=True)
 async def _match_all(
     request: Request,
     type: EndpointsType = EndpointsType.illust,
