@@ -36,7 +36,12 @@ logger.add(
     format=LOG_FORMAT,
     filter=lambda record: record["level"].no < 30,
 )
-logger.add(sys.stderr, level="WARNING", format=LOG_FORMAT)
+logger.add(
+    sys.stderr,
+    level=LOG_LEVEL,
+    filter=lambda record: record["level"].no >= 30,
+    format=LOG_FORMAT,
+)
 logger.add(sentry.BreadcrumbHandler(), level=LOG_LEVEL)
 logger.add(sentry.EventHandler(), level="ERROR")
 logger.level(LOG_LEVEL)
@@ -57,11 +62,11 @@ class LoguruHandler(logging.Handler):
             depth += 1
 
         logger.opt(depth=depth, exception=record.exc_info, colors=True).log(
-            level, ("<e>" + self._escape_tag(message) + "</e>")
+            level, ("<e>" + self.escape_tag(message) + "</e>")
         )
 
     @classmethod
-    def _escape_tag(cls, string: str) -> str:
+    def escape_tag(cls, string: str) -> str:
         return cls._tag_escape_re.sub(r"\\\g<0>", string)
 
 
